# Charles Kurzman and Nafeesa Andrabi, analysis of Carnegie Mellon University Delphia COVID-19 survey data

library(survey)        # svydesign, svytable
library(ggplot2)
library(dplyr)
library(stringr)

# Open csv
setwd("c:/")
r <- read.csv("Andrabi-2020-12-21.csv", stringsAsFactors = FALSE)

# Tested positive
r$testpos <- case_when(
  r$B10a == 1 ~ 100,
  r$B10a != 1 ~ 0,
  r$B8 == 2 ~ 0,
  r$B10 == 3 ~ 0
)
table(r$testpos)

# CREATE DAILY SUMMARY FILE

r$n <- 1
daily <- aggregate(n ~ date, data=r, FUN=sum)
daily$date <- as.Date(daily$date,format="%Y-%m-%d")
daily$endrow <- cumsum(daily$n)
daily$startrow <- lag(daily$endrow) + 1
daily$startrow[1] <- 1

daily$D10yes <- NA
daily$D10yes_se <- NA
daily$D10no <- NA
daily$D10no_se <- NA

for(d in 1:nrow(daily)){

  print(daily$date[d])
  temp <- r[daily$startrow[d]:daily$endrow[d],]
  
  # Incorporate survey weights
  w <- svydesign(ids = ~1, data = temp, weights = ~weight)

  # Run models, get means and standard errors

  # Respondents who worked outside the home
  dailytemp <- svymean(w$variables$testpos[w$variables$D10==1], design = w[w$variables$D10==1], na.rm = TRUE, deff = TRUE)
  daily$D10yes[d] <- coef(dailytemp)
  daily$D10yes_se[d] <- SE(dailytemp)[1]
  
  # Respondents who did not work outside the home
  dailytemp <- svymean(w$variables$testpos[w$variables$D10==2], design = w[w$variables$D10==2], na.rm = TRUE, deff = TRUE)
  daily$D10no[d] <- coef(dailytemp)
  daily$D10no_se[d] <- SE(dailytemp)[1]
  
}
daily

# Calculate confidence intervals from standard errors
sevars <- names(daily)[substr(names(daily), str_length(names(daily))-2, str_length(names(daily)))=="_se"]
sevars
for(sevar in sevars){
  civar <- substr(sevar, 1, str_length(sevar)-3)
  print(civar)
  civar_ci_l <- paste(civar,"_ci_l", sep="")
  civar_ci_u <- paste(civar,"_ci_u", sep="")
  daily[civar_ci_l] <- daily[civar] - (daily[sevar] * 1.96)
  daily[civar_ci_u] <- daily[civar] + (daily[sevar] * 1.96)
}

write.csv(daily, file = "Kurzman-Andrabi-Covid-19-Delphi-Survey-Daily-Summary-2020-12-21.csv", row.names = FALSE)

# Drop days with small samples (<25,000)
daily <- daily[daily$n >= 25000,]

# Figure 1. Respondents who worked outside the home, vs. other respondents, testing positive, by day

D10_testpos_daily <- ggplot(daily[daily$date>="2020-09-01",], aes(x = date)) +
  geom_point(aes(y = D10yes), color="Black", size=0.3) + 
  geom_linerange(aes(ymin = D10yes_ci_l, ymax = D10yes_ci_u), color = "Black", alpha = 0.6) + 
  geom_smooth(aes(y = D10yes), se = FALSE, color = "Black", size=0.3) +
  geom_point(aes(y=D10no), color = "Red", size=0.3) +
  geom_linerange(aes(ymin = D10no_ci_l, ymax = D10no_ci_u), color = "Red", alpha = 0.6) +
  geom_smooth(aes(y = D10no), se = FALSE, color = "Black", size=0.3) +
  theme(panel.background=element_blank()) +
  scale_y_continuous(breaks = seq(0,4, by=0.5)) + expand_limits(y = 0, x = as.Date("2020-09-01")) + expand_limits(y = 3.4) +
  ylab("Percent testing positive for Covid-19 in past 2 weeks") +
  xlab("") +
  scale_x_date(date_breaks = "1 month", date_labels = "%B") +
  annotate(geom="text",x=as.Date("2020-09-08"), y=1.9, label="Respondents who worked outside the home\nin the previous 4 weeks", hjust="left", size=3.5, color="black") +
  annotate(geom="text",x=as.Date("2020-09-08"), y=0.1, label="Other respondents", hjust="left", size=3.5, color="Red") +
  labs(title = "Working Outside the Home and Prevalence of Covid-19 in the United States") +
  labs(subtitle = "September 8-December 18, 2020") +
  labs(caption="Charles Kurzman and Nafeesa Andrabi, UNC-Chapel Hill, December 21, 2020.\nData source: Delphi Research Group, Carnegie Mellon University.", color="black")

D10_testpos_daily

ggsave("Kurzman-Andrabi-Covid-19-and-Working-Outside-Home-2020-12-21.png", D10_testpos_daily, dpi=300, height=4, width=8)
